==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="34"/>
        <source>Qt Multimedia Plugin</source>
        <translation>Plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation>Acerca da saida do plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation>Qmmp Qt Multimedia plugin de saida</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="61"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation>Escrito por: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation>Configuracións do plugin Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation>Por defecto</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.6.orig.tar.bz2: qmmp-1.1.6/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
